@@ -1,47 +1,60 @@
 import base64
 import random
+import requests
 import string
 from typing import Dict, List
 
 from .fixtures import walletclient, walletname, walletpassphrase  # noqa: F401
 
 
+def check_response(r: requests.Response) -> None:
+    assert (
+        r.status_code == 200
+    ), f"{r.url} returned HTTP {r.status_code} {r.text}"
+
+
 def random_metadata() -> List[Dict[str, str]]:
     return [
         {
-            "key": "".join(random.choice(string.ascii_uppercase) for i in range(10)),
-            "value": "".join(random.choice(string.ascii_lowercase) for i in range(10)),
+            "key": "".join(
+                random.choice(string.ascii_uppercase) for i in range(10)
+            ),
+            "value": "".join(
+                random.choice(string.ascii_lowercase) for i in range(10)
+            ),
         }
     ]
 
 
-def test_walletclient(walletclient, walletname, walletpassphrase):  # noqa: F811
+def test_walletclient(
+    walletclient, walletname, walletpassphrase  # noqa: F811
+):
     wname = walletname
     wpass = walletpassphrase
 
     # Create wallet
     r = walletclient.create(wname, wpass)
-    assert r.status_code == 200
+    check_response(r)
     j = r.json()
     assert "token" in j, "Bad response: {}".format(j)
 
     # Log out
     r = walletclient.logout()
-    assert r.status_code == 200
+    check_response(r)
     j = r.json()
     assert "success" in j, "Bad response: {}".format(j)
     assert j["success"] is True
 
     # Log in
     r = walletclient.login(wname, wpass)
-    assert r.status_code == 200
+    check_response(r)
     j = r.json()
     assert "token" in j, "Bad response: {}".format(j)
 
     # Generate keypair
     meta = random_metadata()
     r = walletclient.generatekey(wpass, meta)
-    assert r.status_code == 200
+    check_response(r)
     j = r.json()
     assert "key" in j, "Bad response: {}".format(j)
     k = j["key"]
@@ -49,14 +62,14 @@ def test_walletclient(walletclient, walletname, walletpassphrase):  # noqa: F811
 
     # List keypairs
     r = walletclient.listkeys()
-    assert r.status_code == 200
+    check_response(r)
     j = r.json()
     assert "keys" in j, "Bad response: {}".format(j)
     assert len(j["keys"]) == 1
 
     # Get one keypair
     r = walletclient.getkey(k["pub"])
-    assert r.status_code == 200
+    check_response(r)
     j = r.json()
     assert "key" in j, "Bad response: {}".format(j)
     k2 = j["key"]
@@ -66,7 +79,7 @@ def test_walletclient(walletclient, walletname, walletpassphrase):  # noqa: F811
     blob = b"abc123"
     tx = base64.b64encode(blob).decode("ascii")
     r = walletclient.signtx(tx, k["pub"], False)
-    assert r.status_code == 200
+    check_response(r)
     j = r.json()
     assert "signedTx" in j, "Bad response: {}".format(j)
     signedTx = j["signedTx"]
@@ -76,14 +89,14 @@ def test_walletclient(walletclient, walletname, walletpassphrase):  # noqa: F811
     # Update key metadata
     meta2 = random_metadata()
     r = walletclient.updatekeymetadata(k["pub"], wpass, meta2)
-    assert r.status_code == 200
+    check_response(r)
     j = r.json()
     assert "success" in j, "Bad response: {}".format(j)
     assert j["success"] is True
 
     # Get one keypair, again
     r = walletclient.getkey(k["pub"])
-    assert r.status_code == 200
+    check_response(r)
     j = r.json()
     assert "key" in j, "Bad response: {}".format(j)
     k3 = j["key"]
@@ -91,7 +104,7 @@ def test_walletclient(walletclient, walletname, walletpassphrase):  # noqa: F811
 
     # Taint key
     r = walletclient.taintkey(k["pub"], wpass)
-    assert r.status_code == 200, "Bad response: {}".format(r.text)
+    check_response(r)
     j = r.json()
     assert "success" in j, "Bad response: {}".format(j)
     assert j["success"] is True
